pub fn compile_batch(
batch: &ProjectionImportBatchV3,
policy: &CompilerPolicy,
) -> CompileOutputExpand description
Compiles an importer batch into the bounded inference graph consumed by the kernel lane.
pub fn compile_batch(
batch: &ProjectionImportBatchV3,
policy: &CompilerPolicy,
) -> CompileOutputCompiles an importer batch into the bounded inference graph consumed by the kernel lane.