pub struct CompilationBoundary {
pub from_surface: GraphSurfaceKind,
pub to_surface: GraphSurfaceKind,
pub artifact_families: Vec<String>,
pub deterministic: bool,
}Fields
from_surface: GraphSurfaceKindto_surface: GraphSurfaceKindartifact_families: Vec<String>deterministic: boolTrait Implementations
Sourceimpl Clone for CompilationBoundary
impl Clone for CompilationBoundary
Sourcefn clone(&self) -> CompilationBoundary
fn clone(&self) -> CompilationBoundary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompilationBoundary
impl Debug for CompilationBoundary
Sourceimpl<'de> Deserialize<'de> for CompilationBoundary
impl<'de> Deserialize<'de> for CompilationBoundary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompilationBoundary
Sourceimpl JsonSchema for CompilationBoundary
impl JsonSchema for CompilationBoundary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompilationBoundary
impl PartialEq for CompilationBoundary
Sourcefn eq(&self, other: &CompilationBoundary) -> bool
fn eq(&self, other: &CompilationBoundary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompilationBoundary
impl Serialize for CompilationBoundary
impl StructuralPartialEq for CompilationBoundary