pub struct CompileOutput {
pub graph_hash: ContentDigest,
pub scope_key: ScopeKey,
pub geometry_manifest: GraphGeometryManifest,
pub nodes: Vec<InferenceNode>,
pub hyperedges: Vec<InferenceHyperedge>,
pub constraints: Vec<ConstraintUnit>,
pub regions: Vec<CompiledRegion>,
pub invalidation_cones: Vec<InvalidationCone>,
pub degradations: Vec<ConstraintDegradation>,
pub oracle_candidates: Vec<OracleSliceCandidate>,
}Fields
graph_hash: ContentDigestscope_key: ScopeKeygeometry_manifest: GraphGeometryManifestnodes: Vec<InferenceNode>hyperedges: Vec<InferenceHyperedge>constraints: Vec<ConstraintUnit>regions: Vec<CompiledRegion>invalidation_cones: Vec<InvalidationCone>degradations: Vec<ConstraintDegradation>oracle_candidates: Vec<OracleSliceCandidate>Trait Implementations
Sourceimpl Clone for CompileOutput
impl Clone for CompileOutput
Sourcefn clone(&self) -> CompileOutput
fn clone(&self) -> CompileOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompileOutput
impl Debug for CompileOutput
Sourceimpl<'de> Deserialize<'de> for CompileOutput
impl<'de> Deserialize<'de> for CompileOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompileOutput
Sourceimpl JsonSchema for CompileOutput
impl JsonSchema for CompileOutput
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompileOutput
impl PartialEq for CompileOutput
Sourcefn eq(&self, other: &CompileOutput) -> bool
fn eq(&self, other: &CompileOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompileOutput
impl Serialize for CompileOutput
impl StructuralPartialEq for CompileOutput