pub struct CompiledRegion {
pub region_id: RegionId,
pub region_digest_id: RegionDigestId,
pub node_ids: Vec<String>,
pub hyperedge_ids: Vec<String>,
pub constraint_ids: Vec<ConstraintId>,
pub bounded_default_unit_of_work: bool,
}Fields
region_id: RegionIdregion_digest_id: RegionDigestIdnode_ids: Vec<String>hyperedge_ids: Vec<String>constraint_ids: Vec<ConstraintId>bounded_default_unit_of_work: boolTrait Implementations
Sourceimpl Clone for CompiledRegion
impl Clone for CompiledRegion
Sourcefn clone(&self) -> CompiledRegion
fn clone(&self) -> CompiledRegion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompiledRegion
impl Debug for CompiledRegion
Sourceimpl<'de> Deserialize<'de> for CompiledRegion
impl<'de> Deserialize<'de> for CompiledRegion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompiledRegion
Sourceimpl JsonSchema for CompiledRegion
impl JsonSchema for CompiledRegion
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompiledRegion
impl PartialEq for CompiledRegion
Sourcefn eq(&self, other: &CompiledRegion) -> bool
fn eq(&self, other: &CompiledRegion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompiledRegion
impl Serialize for CompiledRegion
impl StructuralPartialEq for CompiledRegion