pub struct CompilerPolicy {
pub policy_version: String,
pub include_hyperedges: bool,
}Fields
policy_version: Stringinclude_hyperedges: boolTrait Implementations
Sourceimpl Clone for CompilerPolicy
impl Clone for CompilerPolicy
Sourcefn clone(&self) -> CompilerPolicy
fn clone(&self) -> CompilerPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompilerPolicy
impl Debug for CompilerPolicy
Sourceimpl<'de> Deserialize<'de> for CompilerPolicy
impl<'de> Deserialize<'de> for CompilerPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompilerPolicy
Sourceimpl JsonSchema for CompilerPolicy
impl JsonSchema for CompilerPolicy
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompilerPolicy
impl PartialEq for CompilerPolicy
Sourcefn eq(&self, other: &CompilerPolicy) -> bool
fn eq(&self, other: &CompilerPolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompilerPolicy
impl Serialize for CompilerPolicy
impl StructuralPartialEq for CompilerPolicy