pub struct GraphGeometryManifest {
pub surfaces: Vec<GraphSurfaceKind>,
pub compilation_boundaries: Vec<CompilationBoundary>,
pub no_silent_collapse: bool,
}Fields
surfaces: Vec<GraphSurfaceKind>compilation_boundaries: Vec<CompilationBoundary>no_silent_collapse: boolTrait Implementations
Sourceimpl Clone for GraphGeometryManifest
impl Clone for GraphGeometryManifest
Sourcefn clone(&self) -> GraphGeometryManifest
fn clone(&self) -> GraphGeometryManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphGeometryManifest
impl Debug for GraphGeometryManifest
Sourceimpl<'de> Deserialize<'de> for GraphGeometryManifest
impl<'de> Deserialize<'de> for GraphGeometryManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GraphGeometryManifest
Sourceimpl JsonSchema for GraphGeometryManifest
impl JsonSchema for GraphGeometryManifest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GraphGeometryManifest
impl PartialEq for GraphGeometryManifest
Sourcefn eq(&self, other: &GraphGeometryManifest) -> bool
fn eq(&self, other: &GraphGeometryManifest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GraphGeometryManifest
impl Serialize for GraphGeometryManifest
impl StructuralPartialEq for GraphGeometryManifest