pub struct InvalidationCone {
pub source_node_id: String,
pub affected_node_ids: Vec<String>,
pub affected_hyperedge_ids: Vec<String>,
pub affected_constraint_ids: Vec<ConstraintId>,
}Fields
source_node_id: Stringaffected_node_ids: Vec<String>affected_hyperedge_ids: Vec<String>affected_constraint_ids: Vec<ConstraintId>Trait Implementations
Sourceimpl Clone for InvalidationCone
impl Clone for InvalidationCone
Sourcefn clone(&self) -> InvalidationCone
fn clone(&self) -> InvalidationCone
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidationCone
impl Debug for InvalidationCone
Sourceimpl<'de> Deserialize<'de> for InvalidationCone
impl<'de> Deserialize<'de> for InvalidationCone
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InvalidationCone
Sourceimpl JsonSchema for InvalidationCone
impl JsonSchema for InvalidationCone
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InvalidationCone
impl PartialEq for InvalidationCone
Sourcefn eq(&self, other: &InvalidationCone) -> bool
fn eq(&self, other: &InvalidationCone) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InvalidationCone
impl Serialize for InvalidationCone
impl StructuralPartialEq for InvalidationCone